Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrUnsupportedArch = errors.New("beignet: unsupported architecture (supported: darwin/arm64, darwin/amd64)") ErrInvalidMachO = errors.New("beignet: invalid Mach-O") )
Functions ¶
func LoaderCSource ¶
func LoaderCSource() string
LoaderCSource returns the embedded darwin loader C source code.
Types ¶
type Options ¶
type Options struct {
// EntrySymbol is the symbol name to resolve in the loaded module (e.g. "_StartW").
// If provided without a leading underscore, one is added.
EntrySymbol string
// Compress enables aPLib "AP32" safe-packed compression for the staged dylib
// buffer. This reduces shellcode size and requires the embedded loader.
Compress bool
}
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
stager
Code generated by internal/tools/genstager; DO NOT EDIT.
|
Code generated by internal/tools/genstager; DO NOT EDIT. |
|
tools/genstager
command
|
Click to show internal directories.
Click to hide internal directories.